@@ -1,20 +1,9 @@
 /*
     This file is part of the MTP KIOD module, part of the KDE project.
 
-    Copyright (C) 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+    SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mtpdevice.h"
@@ -26,6 +15,7 @@
 #include <Solid/DeviceNotifier>
 
 #include "mtpstorage.h"
+#include "kiod_kmtpd_debug.h"
 
 // D-Bus adaptors
 #include "deviceadaptor.h"
@@ -102,7 +92,7 @@ int MTPDevice::setFriendlyName(const QString &friendlyName)
     const int result = LIBMTP_Set_Friendlyname(m_mtpdevice, friendlyName.toUtf8().constData());
     if (!result) {
         m_friendlyName = friendlyName;
-        emit friendlyNameChanged(m_friendlyName);
+        Q_EMIT friendlyNameChanged(m_friendlyName);
 
     }
     return result;
